;++++++++++++++++++++++++++++++++++++++++++
;+++ sample code drawing GSMaP-bin data +++
;++++++++++++++++++++++++++++++++++++++++++

;+++ input file name
fn_bin = '../../data_07A/gsmap_gauge_now.20211201.0000.dat'

;+++ read GSMaP_bin data
rain_data = fltarr(3600,1200)
openr, 1, fn_bin
readu, 1, rain_data
close, 1

;+++ rotate GSMaP data
rain_data = rotate(rain_data,7)

;+++ convert 1byte scale data for drawing
rain_byte = bytarr(3600,1200)

tdb_rain   = [0,0.1,  0.5, 1,   2,   3,   5,   10,  15,  20,  25,  1000] ; [mm/h]
tdb_r_elem = [255,   0,   0,   0,  51, 155, 255, 255, 255, 235, 175 ]
tdb_g_elem = [255,   0, 100, 180, 219, 235, 235, 179, 100,  30,   0 ]
tdb_b_elem = [255, 150, 250, 250, 128,  74,   0,   0,   0,   0,   0 ]

num_size = size(tdb_r_elem)
num = num_size(1)

for i=0L, num - 1L do begin
 w = where( (tdb_rain[i] le rain_data) and (rain_data lt tdb_rain[i+1L]), cw )
 if (cw ge 1) then begin
  rain_byte(w) = i
 endif
endfor ; i

;+++ set color 
device,retain=2,decomposed=0

tvlct, r, g, b, /get
r[0:num-1L] = tdb_r_elem[*]
g[0:num-1L] = tdb_g_elem[*]
b[0:num-1L] = tdb_b_elem[*]
r[255]=0 & g[255]=0 & b[255]=0
tvlct, r, g, b

;+++ draw on map
window, 0, xsize=800, ysize=400, title='GSMaP_bin'

MAP_SET, 0, 180, /CYLINDRICAL,  $
   LIMIT=[-60, 0, 60, 360], pos=[0.1, 0.1, 0.9, 0.9], $
   /noerase, /NOBORDER

result = MAP_IMAGE(rain_byte, x0, y0, xsize, ysize, $ 
   COMPRESS=1, SCALE=0.05, $
   LATMIN=-60, LONMIN=0, $
   LATMAX=60, LONMAX=360)

TV, result, x0, y0, xsize=xsize, ysize=ysize

map_continents
map_grid, LABEL=1, CHARSIZE=1.0, GLINESTYLE=1, $
          LATLAB=-15, LONLAB=-45, $
          LONDEL=30, LATDEL=10, /BOX_AXES

write_png,'sample_GSMaP_bin_IDL.png',tvrd(/true)

END
